@@ -21,6 +21,7 @@ from .literals import (
     FilterNameType,
     FindingReasonCodeType,
     FindingType,
+    InstanceRecommendationFindingReasonCodeType,
     JobFilterNameType,
     JobStatusType,
     LambdaFunctionMemoryMetricStatisticType,
@@ -31,6 +32,7 @@ from .literals import (
     LambdaFunctionRecommendationFindingType,
     MetricNameType,
     MetricStatisticType,
+    PlatformDifferenceType,
     RecommendationSourceTypeType,
     ResourceTypeType,
     StatusType,
@@ -291,6 +293,7 @@ InstanceRecommendationOptionTypeDef = TypedDict(
     {
         "instanceType": str,
         "projectedUtilizationMetrics": List["UtilizationMetricTypeDef"],
+        "platformDifferences": List[PlatformDifferenceType],
         "performanceRisk": float,
         "rank": int,
     },
@@ -305,6 +308,7 @@ InstanceRecommendationTypeDef = TypedDict(
         "instanceName": str,
         "currentInstanceType": str,
         "finding": FindingType,
+        "findingReasonCodes": List[InstanceRecommendationFindingReasonCodeType],
         "utilizationMetrics": List["UtilizationMetricTypeDef"],
         "lookBackPeriodInDays": float,
         "recommendationOptions": List["InstanceRecommendationOptionTypeDef"],
